@@ -22,13 +22,13 @@ LinearStatistic <- function(x, y, weights) {
     storage.mode(x) <- "double"
     storage.mode(y) <- "double"
     storage.mode(weights) <- "double"
-    .Call("R_LinearStatistic", x, y, weights, PACKAGE = "coin")
+    .Call(R_LinearStatistic, x, y, weights)
 }
 
 ExpectCovarInfluence <- function(y, weights) {
     storage.mode(y) <- "double"
     storage.mode(weights) <- "double"
-    .Call("R_ExpectCovarInfluence", y, weights, PACKAGE = "coin")
+    .Call(R_ExpectCovarInfluence, y, weights)
 }
 
 expectvaronly <- function(x, y, weights) {
@@ -42,9 +42,9 @@ expectvaronly <- function(x, y, weights) {
     rSx <- colSums(x)
     rSx2 <- colSums(x^2)
     ## in case rSx _and_ Ey are _both_ vectors
-    E <- .Call("R_kronecker", Ey, rSx, PACKAGE = "coin")
-    V <- n / (n - 1) * .Call("R_kronecker", Vy, rSx2, PACKAGE = "coin")
-    V <- V - 1 / (n - 1) * .Call("R_kronecker", Vy, rSx^2, PACKAGE = "coin")
+    E <- .Call(R_kronecker, Ey, rSx)
+    V <- n / (n - 1) * .Call(R_kronecker, Vy, rSx2)
+    V <- V - 1 / (n - 1) * .Call(R_kronecker, Vy, rSx^2)
     list(E = drop(E), V = matrix(V, nrow = 1L))
 }
 
@@ -64,12 +64,11 @@ ExpectCovarLinearStatistic <- function(x, y, weights, varonly = FALSE) {
         storage.mode(y) <- "double"
         storage.mode(weights) <- "double"
         expcovinf <- ExpectCovarInfluence(y, weights)
-        .Call("R_ExpectCovarLinearStatistic", x, y, weights, expcovinf,
-               PACKAGE = "coin")
+        .Call(R_ExpectCovarLinearStatistic, x, y, weights, expcovinf)
     }
 }
 
-pmvn <- function(lower, upper, mean, corr, ..., conf.int = TRUE) {
+pmvn <- function(lower, upper, mean, corr, conf.int, ...) {
     p <- if (length(corr) > 1L)
              pmvnorm(lower = lower, upper = upper, mean = mean,
                      corr = corr, ...)
@@ -126,15 +125,15 @@ copyslots <- function(source, target) {
         stop("no common slots to copy to")
     for (s in slots)
         eval(parse(text = paste("target@", s, " <- source@", s)))
-    return(target)
+    target
 }
 
 ft <- function(test, class, formula, data = list(), subset = NULL,
     weights = NULL, ...) {
 
     object <- formula2data(formula, data, subset, weights = weights, ...)
-    object <- new(class, x = object$x, y = object$y, block = object$bl,
-                  weights = object$w)
+    object <- new(class, x = object$x, y = object$y, block = object$block,
+                  weights = object$weights)
     args <- list(...)
     args$frame <- NULL
 
@@ -190,8 +189,8 @@ formula2data <- function(formula, data, subset, weights = NULL, ...) {
     } else
         block <- NULL
 
-    list(x = x, y = y, block = block, bl = block[[1L]],
-         w = if (no_weights) NULL else dat@get("weights")[[1L]])
+    list(x = x, y = y, block = block[[1L]],
+         weights = if (no_weights) NULL else dat@get("weights")[[1L]])
 }
 
 setscores <- function(x, scores) {
@@ -200,13 +199,13 @@ setscores <- function(x, scores) {
 
     varnames <- names(scores)
     if (!is.list(scores) || is.null(varnames))
-       stop(sQuote("scores"), " is not a named list")
+        stop(sQuote("scores"), " is not a named list")
 
     missing <- varnames[!varnames %in% c(colnames(x@x), colnames(x@y))]
     if (length(missing) > 0L)
         stop("Variable(s) ", paste(missing, sep = ", "),
              " not found in ", sQuote("x"))
-
+    ## <FIXME> Repeated reassignment to S4 objects may be expensive
     for (var in varnames) {
         if (!is.null(x@x[[var]])) {
             if (!is.factor(x@x[[var]]))
@@ -214,8 +213,6 @@ setscores <- function(x, scores) {
             if (nlevels(x@x[[var]]) != length(scores[[var]]))
                 stop("scores for variable ", sQuote(var), " don't match")
             x@x[[var]] <- ordered(x@x[[var]], levels = levels(x@x[[var]]))
-            if (nlevels(x@x[[var]]) == 2)
-                scores[[var]] <- 0:1      # must be 0:1 for exact p-values
             attr(x@x[[var]], "scores") <- scores[[var]]
         }
         if (!is.null(x@y[[var]])) {
@@ -224,12 +221,11 @@ setscores <- function(x, scores) {
             if (nlevels(x@y[[var]]) != length(scores[[var]]))
                 stop("scores for variable ", sQuote(var), " don't match")
             x@y[[var]] <- ordered(x@y[[var]], levels = levels(x@y[[var]]))
-            if (nlevels(x@y[[var]]) == 2)
-                scores[[var]] <- 0:1      # must be 0:1 for exact p-values
             attr(x@y[[var]], "scores") <- scores[[var]]
         }
     }
-    return(x)
+    ## </FIXME>
+    x
 }
 
 ### user-supplied trafo functions may return a vector or matrices
@@ -257,7 +253,7 @@ table2df <- function(x) {
     freq <- x[["Freq"]]
     x <- x[rep.int(seq_len(nrow(x)), freq), , drop = FALSE]
     rownames(x) <- seq_len(nrow(x))
-    return(x[, colnames(x) != "Freq"])
+    x[, colnames(x) != "Freq"]
 }
 
 table2df_sym <- function(x) {
@@ -265,8 +261,9 @@ table2df_sym <- function(x) {
     lx <- levels(x[[1L]])
     if (!all(vapply(x, function(x) all(levels(x) == lx), NA)))
         stop("table ", sQuote("x"), " does not represent a symmetry problem")
-    data.frame(conditions = factor(rep.int(colnames(x),
-                                           rep.int(nrow(x), ncol(x)))),
+    data.frame(conditions = factor(rep.int(seq_len(ncol(x)),
+                                           rep.int(nrow(x), ncol(x))),
+                                   labels = colnames(x)),
                response = factor(unlist(x, recursive = FALSE,
                                         use.names = FALSE),
                                  labels = lx))
@@ -383,10 +380,9 @@ isequal <- function(a, b) {
     if (!isTRUE(all.equal(a, b))) {
         print(a, digits = 10)
         print(b, digits = 10)
-        return(FALSE)
-    } else {
-        return(TRUE)
-    }
+        FALSE
+    } else
+        TRUE
 }
 
 has_distribution <- function(args)
@@ -489,15 +485,24 @@ varnames <- function(object) {
 
 eps <- function() sqrt(.Machine$double.eps)
 
-EQ <- function(x, y)
+`%EQ%` <- function(x, y)
     abs(x - y) < eps()
 
-GE <- function(x, y)
+`%NE%` <- function(x, y)
+    abs(x - y) >= eps()
+
+`%GE%` <- function(x, y)
     x > y | abs(x - y) < eps()
 
-LE <- function(x, y)
+`%LE%` <- function(x, y)
     x < y | abs(x - y) < eps()
 
+`%GT%` <- function(x, y)
+    (x - y) >= eps()
+
+`%LT%` <- function(x, y)
+    (y - x) >= eps()
+
 ### don't use! never!
 get_weights <- function(object) object@statistic@weights
 get_xtrans <- function(object) object@statistic@xtrans
@@ -519,15 +524,15 @@ setColnames <- function (object, nm) {
 n_decimal_digits <- function(x)
     nchar(sub("^[[:digit:]]*[.]", "", format(min(x), scientific = FALSE)))
 
-if(getRversion() < "2.15.0")
+if (getRversion() < "2.15.0")
     paste0 <- function(...) paste(..., sep = "")
 
-if(getRversion() < "3.1.0") {
+if (getRversion() < "3.1.0") {
     cospi <- function(x) cos(pi * x)
     anyNA <- function(x) any(is.na(x))
 }
 
-if(getRversion() < "3.2.0") {
+if (getRversion() < "3.2.0") {
     isNamespaceLoaded <- function(name) !is.null(.getNamespace(name))
     lengths <- function(x, use.names = TRUE)
         vapply(x, length, NA_integer_, USE.NAMES = use.names)
