@@ -3,13 +3,23 @@
 set.seed(290875)
 library("coin")
 isequal <- coin:::isequal
-GE <- coin:::GE
+`%GE%` <- coin:::`%GE%`
 options(useFancyQuotes = FALSE)
 
-### I() returns objects of class AsIs which caused an error in `trafo'
-df <- data.frame(x1 = rnorm(100), x2 = rnorm(100), x3 = gl(2, 50))
-independence_test(I(x1 / x2) ~ x3, data = df)
-independence_test(I(x1 < 0) ~ x3, data = df)
+### I() returns objects of class "AsIs" causing errors in 'trafo'
+df <- data.frame(x1 = rnorm(100), x2 = rnorm(100), x3 = gl(2, 50),
+                 x4 = I(letters[1:20]))
+df <- within(df, {
+    x5 <- x1 / x2
+    x6 <- x1 < 0
+})
+it1 <- independence_test(I(x1 / x2) ~ x3, data = df)
+it2 <- independence_test(x5 ~ x3, data = df)
+stopifnot(identical(statistic(it1), statistic(it2))) # was OK
+it3 <- independence_test(I(x1 < 0) ~ x3, data = df)
+it4 <- independence_test(x6 ~ x3, data = df)
+stopifnot(identical(statistic(it3), statistic(it4))) # wrong sign
+try(independence_test(x4 ~ x3, data = df))           # coercion to numeric
 
 ### expectation was wrong when varonly = TRUE in case both
 ### xtrafo and ytrafo were multivariate
@@ -26,7 +36,7 @@ if (require("multcomp")) {
 }
 
 
-### `statistic' for linear and standardized statistics was wrong in case of
+### 'statistic' for linear and standardized statistics was wrong in case of
 ### scores
 data("jobsatisfaction")
 stopifnot(unique(dim(statistic(lbl_test(jobsatisfaction), "linear"))) == 1)
@@ -35,17 +45,21 @@ stopifnot(unique(dim(statistic(lbl_test(jobsatisfaction), "standardized"))) == 1
 
 ### support() failed in most cases
 df <- data.frame(x = runif(20), y = runif(20), z = gl(2, 10))
-support(independence_test(x ~ z, data = df))
-support(independence_test(x ~ z, data = df, teststat = "quad"))
+stopifnot(is.na(support(independence_test(x ~ z, data = df))))
+stopifnot(is.na(support(independence_test(x ~ z, data = df, teststat = "quad"))))
 ite <- independence_test(I(round(x, 1)) ~ z, data = df, dist = exact())
 ae <- support(ite)
-de <- sapply(ae, function(x) dperm(ite, x))
-sum(de)
+de <- dperm(ite, ae)
+stopifnot(isequal(sum(de), 1))
+pe <- pperm(ite, ae)
+stopifnot(isequal(cumsum(de), pe))
 ita <- independence_test(I(round(x, 1)) ~ z, data = df,
                          dist = approximate(B = 100000))
 aa <- support(ita)
-da <- sapply(aa, function(x) dperm(ita, x))
-sum(da)
+da <- dperm(ita, aa)
+stopifnot(isequal(sum(da), 1))
+pa <- pperm(ita, aa)
+stopifnot(isequal(cumsum(da), pa))
 mean(round(ae, 10) %in% round(aa, 10))
 
 plot(aa, da, type = "s", lty = 1)
@@ -133,7 +147,7 @@ for (i in n) {
              -sqrt(.Machine$double.eps))
 }
 
-### formula evaluation in `parent.frame()', spotted by Z
+### formula evaluation in 'parent.frame()', spotted by Z
 foo <- function(x, y) independence_test(y ~ x)
 a <- 1:10
 b <- 1:10
@@ -233,10 +247,10 @@ wte <- wilcox_test(Route.Time ~ Route, distribution = exact())
 wta <- wilcox_test(Route.Time ~ Route, distribution = approximate())
 de <- dperm(wte, support(wte))
 pe <- pperm(wte, support(wte))
-stopifnot(max(abs(cumsum(de) - pe)) < sqrt(.Machine$double.eps))
+stopifnot(isequal(cumsum(de), pe))
 da <- dperm(wta, support(wta))
 pa <- pperm(wta, support(wta))
-stopifnot(max(abs(cumsum(da) - pa)) < sqrt(.Machine$double.eps))
+stopifnot(isequal(cumsum(da), pa))
 qperm(wte, seq(from = 0.1, to = 0.9, by = 0.1))
 qperm(wta, seq(from = 0.1, to = 0.9, by = 0.1))
 
@@ -256,14 +270,6 @@ it <- normal_test(scores ~ fac, data = dat.fr,
     alternative = alternative, dist = exact())
 confint(it)
 
-### discrete (spotted by Henric Winell <henric.winell@sorch.se>)
-set.seed(1)
-x <- gl(3, 5)
-y1 <- rnorm(15)
-y2 <- rnorm(15)
-it <- independence_test(y1 + y2 ~ x, distribution = approximate(B = 5))
-pvalue(it, "discrete") # didn't work
-
 ### error messages
 ### first group completely empty
 x <- c(NA, NA, NA)
@@ -339,7 +345,7 @@ it <- independence_test(y1 + y2 + y3 + y4 ~ x, data = df,
 
 pss <- pvalue(it, "single-step")
 psd <- pvalue(it, "step-down")
-stopifnot(isequal(all(GE(pss, psd)), TRUE))
+stopifnot(isequal(all(pss %GE% psd), TRUE))
 
 ### fmaxstat_trafo 'drop'ed its dimensions
 fmaxstat_trafo(gl(2, 2))
@@ -517,20 +523,16 @@ stopifnot(isequal(qperm(it, c(0.9, 0.95, 0.99)),
 
 ### blockwise permutations were only correct for factors ordered wrt their levels
 set.seed(36)
-.Call("R_blockperm", rep(1:4, 2),                       # was OK
-      PACKAGE = "coin")
+.Call(coin:::R_blockperm, rep(1:4, 2))                       # was OK
 
 set.seed(36)
-.Call("R_blockperm", rep(1:4, each = 2),                # was OK
-      PACKAGE = "coin")
+.Call(coin:::R_blockperm, rep(1:4, each = 2))                # was OK
 
 set.seed(36)
-.Call("R_blockperm", c(1:4, 4:1),                       # was OK
-      PACKAGE = "coin")
+.Call(coin:::R_blockperm, c(1:4, 4:1))                       # was OK
 
 set.seed(36)
-.Call("R_blockperm", c(4L, 1L, 2L, 2L, 4L, 3L, 1L, 3L), # wrong
-      PACKAGE = "coin")
+.Call(coin:::R_blockperm, c(4L, 1L, 2L, 2L, 4L, 3L, 1L, 3L)) # wrong
 
 ### could not distinguish censored and numeric responses
 y1 <- rnorm(10)
@@ -588,3 +590,25 @@ stopifnot(identical(pvalue(it5), pvalue(it8)))
 
 ### 'of_trafo' threw an error for 'x' of length one
 of_trafo(gl(3, 1, ordered = TRUE)[1])
+
+### 'setscores' assigned 0:1 for decreasing scores in 2-level cases
+it1 <- independence_test(y ~ x,  scores = list(x = 1:2)) # was OK
+it2 <- independence_test(y ~ x,  scores = list(x = 2:1)) # wrong sign
+stopifnot(identical(statistic(it1), -statistic(it2)))
+
+### 'of_trafo' didn't return normalized scores in 2-level cases using 'scores'
+x <- gl(2, 1, ordered = TRUE)
+stopifnot(identical(of_trafo(x),                            # was OK
+                    matrix(c(0, 1), dimnames = list(1:2))))
+stopifnot(identical(of_trafo(x, scores = 1:2),              # was 1:2
+                    matrix(c(0, 1), dimnames = list(1:2))))
+stopifnot(identical(of_trafo(x, scores = 2:1),              # was 2:1
+                    matrix(c(1, 0), dimnames = list(1:2))))
+
+### 'logrank_trafo' didn't make sure input was right-censored
+y <- Surv(1:5, event = c(1, 0, 1, 0, 1), type = "left")
+try(logrank_trafo(y))
+
+### 'ofmaxstat_trafo' had the labeling wrong
+of <- ordered(c(1, 1, 2, 3, 3, 4))
+ofmaxstat_trafo(of, minprob = 0.34) # was {1} vs. {2, 3, 4}
